NotificationEvent class

Constructors

NotificationEvent({required String title, required String body, String? type, Map? data})
NotificationEvent.fromMap(Map eventData)
factory

Properties

body String
getter/setter pair
data Map?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited